@@ -27,7 +27,7 @@ can implement problem-specific job control policies.
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 __docformat__ = 'reStructuredText'
-__version__ = '2.0.0 version (SVN $Revision$)'
+__version__ = '2.0.1 version (SVN $Revision$)'
 
 import time
 import os
@@ -64,7 +64,7 @@ class TaskCollection(Task):
         """
         Use the given Controller interface for operations on the job
         associated with this task.
-        """        
+        """
         raise NotImplementedError("Called abstract method TaskCollection.attach() - this should be overridden in derived classes.")
 
     def detach(self):
@@ -229,10 +229,8 @@ class SequentialTaskCollection(TaskCollection):
         Use the given Controller interface for operations on the job
         associated with this task.
         """
-        for task in self.tasks:
-            if not task._attached:
-                task.attach(controller)
-                break
+        if self._current_task is not None:
+            self.tasks[self._current_task].attach(controller)
         Task.attach(self, controller)
 
     def kill(self, **extra_args):
@@ -287,6 +285,7 @@ class SequentialTaskCollection(TaskCollection):
         if self._current_task is None:
             self._current_task = 0
         task = self.tasks[self._current_task]
+        task.attach(self._controller)
         task.submit(resubmit, **extra_args)
         if task.execution.state == Run.State.NEW:
             # submission failed, state unchanged
