@@ -20,7 +20,7 @@ Implementation of the `core` command-line front-ends.
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 __docformat__ = 'reStructuredText'
-__version__ = '2.0.0 version (SVN $Revision: 2991 $)'
+__version__ = '2.0.1 version (SVN $Revision: 3196 $)'
 __author__ = "Sergio Maffioletti <sergio.maffioletti@gc3.uzh.ch>, "
 "Riccardo Murri <riccardo.murri@uzh.ch>"
 "Antonio Messina <arcimboldo@gmail.com>"
@@ -895,7 +895,7 @@ To get detaileid info on a specific command, run:
         subparser.set_defaults(func=func)
         subparser.add_argument('session')
         subparser.add_argument('-v', '--verbose', action='count')
-
+        return subparser
 
     def setup(self):
         gc3libs.cmdline._Script.setup(self)
@@ -913,10 +913,12 @@ To get detaileid info on a specific command, run:
             'delete',
             self.delete_session,
             help="Delete a session from disk.")
-        self._add_subcmd(
+        subparser = self._add_subcmd(
             'list',
             self.list_jobs,
             help="List jobs related to a session.")
+        subparser.add_argument('-r', '--recursive', action="store_true", default=False,
+                            help="Show all jobs contained in a task collection, not only top-level jobs.")
 
         self._add_subcmd(
             'log',
@@ -946,12 +948,32 @@ To get detaileid info on a specific command, run:
         except gc3libs.exceptions.InvalidArgument, ex:
             raise RuntimeError('Session %s not found. Please specify a valid session directory as argument' % self.params.session)
 
-        for task_id in self.session.tasks:
-            self.session.tasks[task_id].kill()
+        rc = 0
+        for task_id in self.session.tasks.keys():
+            task = self.session.tasks[task_id]
+            task.attach(self._core)
+            if task.execution.state == Run.State.TERMINATED:
+                gc3libs.log.info("Not aborting '%s' which is already in TERMINATED state." % task)
+                rc += 1
+                continue
+            try:
+                task.kill()
+            except Exception, ex:
+                gc3libs.log.error(
+                    "Failed while killing job '%s'"
+                    "Error type %s, message %s" % (ex.__class__, ex))
+            finally:
+                task.free()
+                rc += 1
             self.session.remove(task_id)
+
         if self.session.tasks:
-            raise RuntimeError("Not all tasks have been removed from the session")
-        return 0
+            gc3libs.log.error("Not all tasks have been removed from the session.")
+
+        if rc > 125:
+            # 126 and 127 error codes have special meanings.
+            rc = 125
+        return rc
 
     def delete_session(self):
         """
@@ -988,10 +1010,33 @@ To get detaileid info on a specific command, run:
         except gc3libs.exceptions.InvalidArgument, ex:
             raise RuntimeError('Session %s not found. Please specify a valid session directory as argument' % self.params.session)
 
-        job_ids = self.session.tasks.keys()
-        cmd = gc3utils.commands.cmd_gstat
-        sys.argv = ['gstat', '-n', '-s', self.params.session] + job_ids
-        return cmd().run()
+
+        def print_app_table(app, indent, recursive):
+            rows = []
+            try:
+                jobname = app.jobname
+            except AttributeError:
+                jobname = ''
+            
+            rows.append([indent + app.persistent_id,
+                         jobname,
+                         app.execution.state,
+                         app.execution.info])
+            if recursive and 'tasks' in app:
+                indent = " "*len(indent) + '  '
+                for task in app.tasks:
+                    rows.extend(print_app_table(task, indent , recursive))
+            return rows
+
+        rows = []
+        for app in self.session.tasks.values():
+            rows.extend(print_app_table(app, '', self.params.recursive))
+        table = Texttable(0)  # max_width=0 => dynamically resize cells
+        table.set_deco(Texttable.HEADER)  # also: .VLINES, .HLINES .BORDER
+        table.set_cols_align(['l'] * 4)
+        table.header(["JobID", "Job name", "State", "Info"])
+        table.add_rows(rows, header=False)
+        print(table.draw())
 
     def show_log(self):
         """
